/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.java.util.metrics.cgroups;

import java.nio.file.Path;
import java.nio.file.Paths;

public class ProcSelfCgroupDiscoverer implements CgroupDiscoverer
{
  private final CgroupDiscoverer delegate;

  public ProcSelfCgroupDiscoverer()
  {
    this(ProcCgroupDiscoverer.class);
  }

  public ProcSelfCgroupDiscoverer(Class<? extends CgroupDiscoverer> discoverer)
  {
    try {
      delegate = discoverer.getDeclaredConstructor(Path.class).newInstance(Paths.get("/proc/self"));
    }
    catch (Exception e) {
      throw new RuntimeException(e);
    }
  }

  @Override
  public Path discover(String cgroup)
  {
    return delegate.discover(cgroup);
  }
}
